@@ -40,7 +40,6 @@ COMMENTAIRE :
 #include "dvdinfo.h"
 #include "message.h"
 #include "gconfig.h"
-#include "tampon.h"
 #include "interface.h"
 #include "globals.h"
 #include "systools.h"
@@ -57,6 +56,7 @@ COMMENTAIRE :
 #include "vapcontext.h"
 #include "mpeg2dec.h"
 #include "profile.h"
+#include "asyncwriter.h"
 
 static char TitreDvd[128];
 
@@ -69,7 +69,6 @@ static long long OutSize;
 static long long TotalSize;
 
 static int CurVOB;
-static uint32_t Position;
 
 static unsigned char TempBuf[DVD_VIDEO_LB_LEN * 2];
 static int TempSize = 0;
@@ -84,34 +83,42 @@ typedef struct {
 	int	scaleY;
 	double	aspect;
 	int	audioTrackId;
+	char *	audioFormat; /* For specific lpcm audio */
 } EncodingInfos_t;
 
 
-/*@$#[dvd2avi.c] static proto. AutoProtoSigV1.1. date: 2009/02/04 23:12:47 */
+#define MEM_2GIG		( 2LL * 1024LL * 1024LL * 1024LL )
+#define MEM_1GIG		( 1LL * 1024LL * 1024LL * 1024LL )
+
+#define MIN_SECTORS4CROP	60000
+
+/*@$#[dvd2avi.c] static proto. AutoProtoSigV1.1. date: 2010/02/02 21:16:25 */
 #include "proto.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
-/* dvd2avi.c */
-static int Output PROTO((unsigned char *buffer, int len, char *targetDir));
-static void MakeRoom PROTO((VapContext_t *c, int size));
-static uint32_t _FindNextVobu PROTO((VapContext_t *c));
-static int Readin PROTO((void *parm, unsigned char *buffer, int size));
-static int OutputFlux PROTO((void *parm, unsigned char *buffer, int size));
-static int CopyCell PROTO((Cell_t *c, char *targetDir));
-static void FreeAll PROTO((void));
-static int _readline PROTO((FILE *fp, char *line, int size));
-static int ExecuteFfmpeg PROTO((char *sysCmd, int duree));
-static int ExecuteMencoder PROTO((char *sysCmd, int duree));
-static double GetAspectRatio PROTO((int noPisteVideo));
-static void GetPictureSizes PROTO((int noPisteVideo, Profile_t *p, int cx, int cy, int *sx, int *sy, int bitrate));
-static int CropDetection PROTO((char *iFile, char *cropParam));
-static char *ComputeCmdLine PROTO((Profile_t *profile, EncodingInfos_t *infos, int passNo));
-static long long GetVobSize PROTO((int noPisteVideo));
+static int Output(unsigned char *buffer, int len, char *targetDir);
+static void MakeRoom(VapContext_t *c, int size);
+static uint32_t _FindNextVobu(VapContext_t *c);
+static int Readin(void *parm, unsigned char *buffer, int size);
+static int OutputFlux(void *parm, unsigned char *buffer, int size);
+static int CopyCell(Cell_t *c, char *targetDir);
+static void FreeAll(void);
+static int _readline(FILE *fp, char *line, int size);
+static int ExecuteFfmpeg(char *sysCmd, int duree);
+static int ExecuteMencoder(char *sysCmd, int duree);
+static double GetAspectRatio(int noPisteVideo);
+static void GetPictureSizes(int noPisteVideo, Profile_t *p, int cx, int cy, int *sx, int *sy, int bitrate);
+static int CropDetection(char *iFile, char *cropParam, int duree, int startPos);
+static char *ComputeCmdLine(Profile_t *profile, EncodingInfos_t *infos, int passNo);
+static long long GetVobSize(int noPisteVideo, int breakFirstCellF);
+static void InitGlobVars(void);
+static void VisuAvi(char *path);
+static int DvdToAviFifo(GtkWidget *forme, int noPisteVideo, AudioMap_t *audioMap, SubMap_t *subMap, int format);
 #ifdef __cplusplus
 }
 #endif
-/*@$% end of AutoProtoSigV1.1 (Dont remove this line) [-I ../include]*/
+/*@$% end of AutoProtoSigV1.1 (Dont remove this line) []*/
 
 /*------------------------------------------------------------------------------
 	OUTPUT-
@@ -144,7 +151,6 @@ char * targetDir;
 		OutSize += DVD_VIDEO_LB_LEN;
 		TotalSize += DVD_VIDEO_LB_LEN;
 		SetTotalSize( TotalSize );
-		Position++;
 		TempSize -= DVD_VIDEO_LB_LEN;
 		if( TempSize > 0 )	tc_memcpy( cBuff, cBuff + DVD_VIDEO_LB_LEN, TempSize );
 	}
@@ -257,7 +263,7 @@ static int Readin( void * parm, unsigned char * buffer, int size )
 	c->bufSize += len;
 
 	Avancement( len );
-	if( AvancementUi( NULL ) < 0 )	return( -1 );
+	if( AvancementUi() < 0 )	return( -1 );
 	if( badNavPack ) {
 		MakeRoom( c, 1 * DVD_VIDEO_LB_LEN );
 		CreateDummyPack( c->bufPtr + DVD_VIDEO_LB_LEN );
@@ -293,7 +299,7 @@ static int Readin( void * parm, unsigned char * buffer, int size )
 	c->bufSize += len;
 
 	Avancement( len );
-	if( AvancementUi( NULL ) < 0 )	return( -1 );
+	if( AvancementUi() < 0 )	return( -1 );
 	if( badNavPack ) {
 		c->sector = c->dsi_next_vobu;
 		c->dsi_next_vobu  = 0;
@@ -549,9 +555,9 @@ static double GetAspectRatio( int noPisteVideo )
 
 static void GetPictureSizes( int noPisteVideo, Profile_t * p, int cx, int cy, int * sx, int * sy, int bitrate )
 {
-	char *aspect_ratio[4] = {"4:3", "16:9", "4:3", "16:9"};
-	double video_height[4] = { 480, 576, 576, 576 };
-	double video_width[4]  = { 720, 704, 352, 352};
+	char *aspect_ratio[4] =  { "4:3",	"16:9",	"4:3",	"16:9"};
+	double video_height[4] = { 480,		576,	576,	576 };
+	double video_width[4]  = { 720,		720,	352,	352 };
 	ifo_handle_t * ifo = Ifo[Ifo_zero->tt_srpt->title[noPisteVideo].title_set_nr];
 	vtsi_mat_t *vtsi_mat = ifo->vtsi_mat;
 	video_attr_t *video_attr;
@@ -603,15 +609,16 @@ static void GetPictureSizes( int noPisteVideo, Profile_t * p, int cx, int cy, in
  * @param[out]	Pas de detail
 *******************************************************************************/
 
-static int CropDetection( char * iFile, char * cropParam )
+static int CropDetection( char * iFile, char * cropParam, int duree, int startPos )
 {
 	char sysCmd[1024];
 	FILE * fp;
 	char line[1024];
 	int res = 0;
 	double lPct = -1;
-	int duree = 60;
+/*	int duree = 60;
 	int startPos = 120;
+*/
 	int frames = duree * 25;
 
 	*cropParam = 0;
@@ -742,6 +749,14 @@ static char * ComputeCmdLine( Profile_t * profile, EncodingInfos_t * infos, int
 		iLine++;
 	}
 	*p = 0;
+/* Handle special case: lpcm audio track doesn't support -aoc copy instead use -oac pcm */
+	if( !strcmp( infos->audioFormat, "lpcm") ){
+		char * p = strstr( oLine, "-oac copy" );
+
+		if( p ) {
+			memcpy( p, "-oac pcm ", 9);
+		}
+	}
 	return( oLine );
 }
 /***************************************************************************//**
@@ -756,7 +771,7 @@ static char * ComputeCmdLine( Profile_t * profile, EncodingInfos_t * infos, int
  * @param[out]	Pas de detail
 *******************************************************************************/
 
-static long long GetVobSize( int noPisteVideo )
+static long long GetVobSize( int noPisteVideo, int breakFirstCellF )
 {
 	int totalSectors = 0;
 	int i;
@@ -764,12 +779,32 @@ static long long GetVobSize( int noPisteVideo )
 	for( i = 0; i < CellArray.nbCells; i++ ) {
 		Cell_t * c = CellArray.cells + i;
 
-		if( c->selected )	totalSectors += SECTOR_SZ(c);
+		if( c->selected ) {
+			totalSectors += SECTOR_SZ(c);
+			if( breakFirstCellF )	break;
+		}
 	}
 	return( (long long)totalSectors * (long long) DVD_BLOCK_LEN );
 }
 
-
+/***************************************************************************//**
+ *	INITGLOBVARS-
+ * @date	2010/02/02 20:46:35
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+static void InitGlobVars()
+{
+	CurVTS = 0;
+	CurVOB = 0;
+	OutSize = 0;
+	TotalSize = 0;
+}
 /*------------------------------------------------------------------------------
 	COPYDVD-
 Linux!jef 2005/12/12 22:36:50
@@ -797,12 +832,17 @@ int DvdToAvi( GtkWidget * forme, int noPisteVideo, AudioMap_t * audioMap, SubMap
 	int aviDone = 0;
 	long long fsize;
 	int nbAudio = 0;
+	Timer_t * timer = NULL;
 
 	DBG('b',fprintf(stderr,"%s: format: %d\n", __FUNCTION__, format ););
 	if( !profile )	return(-1);
 
+	if( profile->useFifo && GetNumCpu() >= 2 ) {
+		return( DvdToAviFifo( forme, noPisteVideo, audioMap, subMap , format ) );
+	}
+
 /* Verify we have enought free space to extract */
-	fsize = FsFree( tmpDir ) - GetVobSize( noPisteVideo );
+	fsize = FsFree( tmpDir ) - GetVobSize( noPisteVideo, 0 );
 	if( fsize < 0 ) {
 		PlayError();
 		MessageBoxError( _("Pas assez de place sur %s\nIl manque %s octets !"), tmpDir, LLSize2Giga( -fsize ) );
@@ -840,13 +880,10 @@ int DvdToAvi( GtkWidget * forme, int noPisteVideo, AudioMap_t * audioMap, SubMap
 	strcpy( TitreDvd, text );
 
 	FreeCellArray( &CellArray );
-	BuildCells( noPisteVideo, &CellArray, lastCellF );
+	BuildCells( noPisteVideo, &CellArray, lastCellF, 1 );
 
 
-	CurVTS = 0;
-	CurVOB = 0;
-	OutSize = 0;
-	TotalSize = 0;
+	InitGlobVars();
 	CreateAvancement( forme );
 
 	nbSteps = CountSelectedCells( &CellArray ) + profile->passNb;
@@ -877,6 +914,7 @@ int DvdToAvi( GtkWidget * forme, int noPisteVideo, AudioMap_t * audioMap, SubMap
 		DestroyAvancement();
 		return( -1 );
 	}
+	timer = StartTimer();
 
 /* Setup vaporizer */
 	if( VaporizeInit( Readin, OutputFlux, 1 ) < 0 ) {
@@ -955,7 +993,7 @@ doAvi:;
 
 		DBG( 'b',fprintf(stderr,"Bitrate: %dK\n", infos.bitrate ););
 		*cropParam = 0;
-		CropDetection( vobFile, cropParam );
+		CropDetection( vobFile, cropParam, 60, 120 );
 		infos.cropParam = cropParam;
 /* Parse croping params */
 		if( sscanf( cropParam, "%d:%d:%d:%d", &cx,&cy,&dx,&dy ) != 4 ) {
@@ -971,6 +1009,7 @@ doAvi:;
 		for( i = 0; i < MAX_AUDIO_TRACK; i++ ) {
 			if( audioMap->audioTracks[i] ) {
 				infos.audioTrackId = AudioStreamId( noPisteVideo, i );
+				infos.audioFormat = AudioFormat( noPisteVideo, i );
 			}
 		}
 
@@ -1007,6 +1046,11 @@ doAvi:;
 		}
 		aviDone = 1;
 	}
+
+	StopTimer( timer );
+	DBG( 'b',fprintf(stderr,"Encoding last: %f\n", ElapsedTimer(timer) ););
+	FreeTimer( timer );
+
 	DestroyAvancement();
 	FreeAll();
 	if( !ret )
@@ -1018,7 +1062,10 @@ doAvi:;
 		if( res != 1 )	vobOk = 0;
 	}
 	if( !vobOk )	unlink( vobFile );
-
+	if( ret == 0 && aviDone ) {
+		res = MessageBoxYesNo( _("Visualiser le fichier %s ?"),  aviFile );
+		if( res == 1 )	VisuAvi( aviFile );
+	}
 	if( ret == -1 && aviDone ) {
 		res = MessageBoxYesNo( _("Conserver le fichier %s ?"),  aviFile );
 		if( res != 1 )	unlink( aviFile );
@@ -1026,3 +1073,399 @@ doAvi:;
 	unlink( logFile );
 	return( ret );
 }
+/***************************************************************************//**
+ *	VISUAVI-
+ * @date	2010/01/27 21:55:54
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+
+static void VisuAvi( path )
+char * path;
+{
+	char * player = ConfigGetString( KEY_PLAYER, "xine" );
+	char sysCmd[1024];
+	int res;
+
+	if( !strcmp( player, "xine" )) {
+		sprintf( sysCmd, "xine \"file://%s\"", path );
+		DBG('c',fprintf(stderr,"%s: executing (%s)\n", __FUNCTION__, sysCmd ););
+		res = system( sysCmd );
+		return;
+	}
+	if( !strcmp( player, "mplayer" )) {
+		sprintf( sysCmd, "mplayer \"%s\"", path );
+		DBG('c',fprintf(stderr,"%s: executing (%s)\n", __FUNCTION__, sysCmd ););
+		res = system( sysCmd );
+		return;
+	}
+	if( !strcmp( player, "vlc" )) {
+		sprintf( sysCmd, "vlc \"%s\"", path );
+		DBG('c',fprintf(stderr,"%s: executing (%s)\n", __FUNCTION__, sysCmd ););
+		res = system( sysCmd );
+		return;
+	}
+}
+
+/***************************************************************************//**
+ *	OUTPUTFLUXFIFO-
+ * @date	2010/02/03 22:30:57
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+static int OutputFluxFifo( void * parm, unsigned char * buffer, int size )
+{
+	if( size >= DVD_VIDEO_LB_LEN ) {
+		if( !isNavPack( buffer ) ) {
+			Mpeg2Demux( buffer, DVD_VIDEO_LB_LEN );
+		}
+	}
+	if( FlusherWrite( buffer, size ) < 0 )	return( -1 );
+	OutSize += size;
+	TotalSize += size;
+	SetTotalSize( TotalSize );
+	return( size );
+}
+
+
+/***************************************************************************//**
+ *	DVDTOAVIFIFO-
+ * @date	2010/02/02 20:41:35
+ * @author	jef-Linux
+ * @brief
+ *	Idem DvdToAvi but with system fifo
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+
+static int DvdToAviFifo( GtkWidget * forme, int noPisteVideo, AudioMap_t * audioMap, SubMap_t * subMap, int format )
+{
+	GtkWidget * item;
+	char * tmpDir = ConfigGetString( KEY_TEMP, "/tmp" );
+	char * isoDir = ConfigGetString( KEY_ISODIR, GetEnv( "HOME", "/tmp" ) );
+	int lastCellF = ConfigGetInt( KEY_GENERIQUE, 0 );
+	char targetDir[512];
+	char vobFile[1024];
+	char aviFile[1024];
+	char logFile[1024];
+	char cropParam[1024];
+	EncodingInfos_t infos;
+	char * cmdLine;
+	int i;
+	char injectionFile[100];
+	const gchar * text;
+	int ret = 0;
+	int res;
+	int nbSteps;
+	int duree;
+	Profile_t * profile = GetProfile( format );
+	long long fsize;
+	int nbAudio = 0;
+	Timer_t * timer = NULL;
+	int bufferSize;
+	long long memSize;
+	int sectorsRead;
+
+	DBG('b',fprintf(stderr,"%s: format: %d\n", __FUNCTION__, format ););
+	if( !profile )	return(-1);
+	if( profile->passNb != 1 )	return( -1 ); /* Multi-pass encoding not supported (profile.c error) */
+
+/* Verify we have enought free space to extract thirst cell (crop detection)*/
+	fsize = FsFree( tmpDir ) - GetVobSize( noPisteVideo, 1 );
+	if( fsize < 0 ) {
+		PlayError();
+		MessageBoxError( _("Pas assez de place sur %s\nIl manque %s octets !"), tmpDir, LLSize2Giga( -fsize ) );
+		return( -1 );
+	}
+/* Verify we have enought free space to encode */
+	fsize = FsFree( isoDir ) - profile->fileSize;
+	if( fsize < 0 ) {
+		PlayError();
+		MessageBoxError( _("Pas assez de place sur %s\nIl manque %s octets !"), isoDir, LLSize2Giga( -fsize ) );
+		return( -1 );
+	}
+/* Verify that we can create a file on isodir */
+	if( CanCreateFile( isoDir ) == 0 ) {
+		PlayError();
+		MessageBoxError( _("Pas le droit de créer de fichier dans %s !"), isoDir );
+		return( -1 );
+	}
+/* Verify number of audio tracks selected */
+	for( i = 0; i < MAX_AUDIO_TRACK; i++ ) {
+		if( audioMap->audioTracks[i] ) {
+			nbAudio++;
+			DBG('b',fprintf(stderr,"%s: audioTrackId: %d=0x%x\n", __FUNCTION__, i, AudioStreamId( noPisteVideo, i ) ););
+		}
+	}
+	if( nbAudio != 1 ) {
+		PlayError();
+		MessageBoxError( _("Sélectionnez qu'un seule piste audio !") );
+		return( -1 );
+	}
+
+/* Reprise du titre du DVD */
+	item = lookup_widget(GTK_WIDGET(forme), "titre" );
+	text = gtk_entry_get_text( GTK_ENTRY(item) );
+	strcpy( TitreDvd, text );
+
+	FreeCellArray( &CellArray );
+	BuildCells( noPisteVideo, &CellArray, lastCellF, 1 );
+
+	InitGlobVars();
+
+	CreateAvancement( forme );
+
+	nbSteps = CountSelectedCells( &CellArray )  + 1 /* For crop detection */;
+	SetTotalSteps( nbSteps );
+
+	DisplayAvancement( _("Copie de %d cellules.\n"), CountSelectedCells( &CellArray ) );
+/*	Create empty filesystem tree */
+	DisplayAvancement( _("Effacement des anciens fichiers.\n"));
+
+	sprintf( injectionFile, "%s/vapinj.%d", tmpDir, getpid());
+	sprintf( targetDir, "%s/%s", tmpDir, TitreDvd );
+	sprintf( aviFile, "%s/%s.%s", isoDir, TitreDvd, profile->extension );
+	sprintf( vobFile, "%s/%s.vob", tmpDir, TitreDvd );
+	sprintf( logFile, "%s/%s.log", tmpDir, TitreDvd );
+
+	timer = StartTimer();
+
+/* Rip first chapter in order to calculate crop parameters */
+	unlink( vobFile ); /* In case of previous failure in encoding stage */
+	OutFpVideo = fopen64( vobFile, "w" );
+	if( !OutFpVideo ) {
+		PlayError();
+		MessageBoxError( _("Création de %s impossible !"), vobFile );
+		DestroyAvancement();
+		return( -1 );
+	}
+
+/* Setup vaporizer */
+	if( VaporizeInit( Readin, OutputFlux, 1 ) < 0 ) {
+		ret = -1; goto out;
+	}
+/* Setup tracks & factor */
+	for( i = 0; i < MAX_AUDIO_TRACK; i++ ) {
+		if( audioMap->audioTracks[i] ) {
+			int id = GetAudioId( noPisteVideo, i );
+
+			DBG('b',fprintf(stderr,"%s: VaporizeAudio(%d)\n", __FUNCTION__, id ););
+			VaporizeAudio( id );
+		}
+	}
+	Mpeg2Init();
+/* Must be 100% */
+	VaporizeFactor( 1.0f, 0 );
+	VaporizeInjection( injectionFile );
+
+/* Copy enought cells to do croping detection */
+	sectorsRead = 0;
+	for( i = 0; i < CellArray.nbCells; i++ ) {
+		Cell_t * c = CellArray.cells + i;
+
+		if( CopyCell( c, targetDir ) < 0 ) {
+			ret = -1;
+			goto out;
+		}
+		if( c->selected ) {
+			c->done = 0;
+			sectorsRead += SECTOR_SZ( c );
+			if( sectorsRead >= MIN_SECTORS4CROP )
+				break;
+		}
+	}
+	NewStep();
+
+	{
+		int vVideoSize;
+		int vAudioSize;
+		int vSubpSize;
+		int vNavSize;
+
+		VaporizeSizes( &vVideoSize, &vAudioSize, &vSubpSize, &vNavSize );
+
+		DBG( 'b',fprintf(stderr,"VAPORIZE VIDEO SIZE: %lld\n", (long long)vVideoSize * DVD_BLOCK_LEN ););
+		DBG( 'b',fprintf(stderr,"VAPORIZE AUDIO SIZE: %lld\n", (long long)vAudioSize * DVD_BLOCK_LEN ););
+		DBG( 'b',fprintf(stderr,"VAPORIZE SUBP  SIZE: %lld\n", (long long)vSubpSize * DVD_BLOCK_LEN ););
+		DBG( 'b',fprintf(stderr,"VAPORIZE NAV   SIZE: %lld\n", (long long)vNavSize * DVD_BLOCK_LEN ););
+	}
+out:;
+
+	VaporizeTerm();
+
+	if( OutFpVideo ) { fclose( OutFpVideo ); OutFpVideo = NULL; }
+
+	Mpeg2End();
+
+/* Here calculate bitrate */
+	if( !ret ) {
+		double audioSize;
+		double videoSize;
+		double bitrate;
+		int cx,cy,dx,dy;
+
+		TotalAudioSize( noPisteVideo, &duree );
+		infos.aspect = GetAspectRatio( noPisteVideo );
+
+		audioSize = ( (double)profile->audioBitrate * (double)duree ) / 8.0;
+		videoSize = profile->fileSize - audioSize;
+		videoSize -= videoSize * profile->overhead; /* Apply container overhead */
+		bitrate = ( videoSize * 8.0 ) / (double)duree;
+		bitrate /= 1000;
+		infos.bitrate = rint(bitrate);
+
+		DBG( 'b',fprintf(stderr,"Bitrate: %dK\n", infos.bitrate ););
+		*cropParam = 0;
+		CropDetection( vobFile, cropParam, 60, 0 );
+		infos.cropParam = cropParam;
+/* Parse croping params */
+		if( sscanf( cropParam, "%d:%d:%d:%d", &cx,&cy,&dx,&dy ) != 4 ) {
+			cx = 720;
+			cy = 576;
+		}
+		GetPictureSizes( noPisteVideo, profile, cx, cy, &infos.scaleX, &infos.scaleY, infos.bitrate );
+
+		DBG( 'b',fprintf(stderr,"ImageParameter: crop(%s) scale(%d,%d)\n", infos.cropParam, infos.scaleX, infos.scaleY ););
+
+		infos.vobFile = vobFile;
+		infos.aviFile = aviFile;
+		infos.logFile = logFile;
+
+/* Establish Audio Track Id to support -aid mencoder option */
+		for( i = 0; i < MAX_AUDIO_TRACK; i++ ) {
+			if( audioMap->audioTracks[i] ) {
+				infos.audioTrackId = AudioStreamId( noPisteVideo, i );
+				infos.audioFormat = AudioFormat( noPisteVideo, i );
+			}
+		}
+	}
+	unlink( vobFile );
+
+	if( ret == -1 ) {
+		DestroyAvancement();
+		FreeAll();
+		PlayError();
+		return( ret );
+	}
+
+/* Ok then we can proceed with fifo method */
+/* Create Fifo file */
+	ret = mkfifo( vobFile, 0666 );
+	if( ret == -1 ) {
+		DBG( 'b',fprintf(stderr,"mkfifo(%s) failed errno: %d\n", vobFile, errno ););
+		DestroyAvancement();
+		FreeAll();
+		PlayError();
+		return( ret );
+	}
+/* Build Cmd line and launch encoder */
+	cmdLine = ComputeCmdLine( profile, &infos, 1 );
+	strcat( cmdLine, " > /dev/null &" );
+	DBG( 'b',fprintf(stderr,"COMMAND LINE(%s)\n", cmdLine ););
+	system( cmdLine );
+/* Copy cells */
+	OutFpVideo = fopen64( vobFile, "w" );
+	if( !OutFpVideo ) {
+		unlink( vobFile );
+		PlayError();
+		MessageBoxError( _("Création de %s impossible !"), vobFile );
+		DestroyAvancement();
+		return( -1 );
+	}
+	InitGlobVars();
+/* Ok we need to mask DVD latency, so having to allocate big buffers, so just verify that whe have enought RAM to do this */
+
+	memSize = CpuPhysMemSize();
+	if( memSize >= MEM_2GIG )	bufferSize = 200; /* 200 mo buffering */
+	else {
+		if( memSize >= MEM_1GIG )	bufferSize = 100; /* 100 mo buffering */
+		else				bufferSize = 50; /* 50 mo buffering */
+	}
+	DBG( 'b',fprintf(stderr,"FlusherStart: bufferSize=%d\n", bufferSize ););
+
+	if( FlusherStart( OutFpVideo, bufferSize ) < 0 ) {
+		ret = -1; goto out2;
+	}
+/* Setup vaporizer */
+	if( VaporizeInit( Readin, OutputFluxFifo, 1 ) < 0 ) {
+		ret = -1; goto out2;
+	}
+/* Setup tracks */
+	for( i = 0; i < MAX_AUDIO_TRACK; i++ ) {
+		if( audioMap->audioTracks[i] ) {
+			int id = GetAudioId( noPisteVideo, i );
+
+			DBG('b',fprintf(stderr,"%s: VaporizeAudio(%d)\n", __FUNCTION__, id ););
+			VaporizeAudio( id );
+		}
+	}
+	Mpeg2Init();
+/* Must be 100% */
+	VaporizeFactor( 1.0f, 0 );
+	VaporizeInjection( injectionFile );
+/* Copy each cell */
+	for( i = 0; i < CellArray.nbCells; i++ ) {
+		Cell_t * c = CellArray.cells + i;
+
+		if( CopyCell( c, targetDir ) < 0 ) {
+			ret = -1;
+			goto out2;
+		}
+		if( c->selected ) NewStep();
+	}
+
+	{
+		int vVideoSize;
+		int vAudioSize;
+		int vSubpSize;
+		int vNavSize;
+
+		VaporizeSizes( &vVideoSize, &vAudioSize, &vSubpSize, &vNavSize );
+
+		DBG( 'b',fprintf(stderr,"VAPORIZE VIDEO SIZE: %lld\n", (long long)vVideoSize * DVD_BLOCK_LEN ););
+		DBG( 'b',fprintf(stderr,"VAPORIZE AUDIO SIZE: %lld\n", (long long)vAudioSize * DVD_BLOCK_LEN ););
+		DBG( 'b',fprintf(stderr,"VAPORIZE SUBP  SIZE: %lld\n", (long long)vSubpSize * DVD_BLOCK_LEN ););
+		DBG( 'b',fprintf(stderr,"VAPORIZE NAV   SIZE: %lld\n", (long long)vNavSize * DVD_BLOCK_LEN ););
+	}
+out2:;
+
+	VaporizeTerm();
+
+	if( FlusherStop() < 0 )	ret = -1;
+
+	if( OutFpVideo ) { fclose( OutFpVideo ); OutFpVideo = NULL; }
+
+	Mpeg2End();
+/* Finish */
+	free( cmdLine );
+	unlink( vobFile );
+	DestroyAvancement();
+	FreeAll();
+
+	StopTimer( timer );
+	DBG( 'b',fprintf(stderr,"Encoding last: %f\n", ElapsedTimer(timer) ););
+	FreeTimer( timer );
+
+	if( !ret )
+		PlaySuccess();
+	else
+		PlayError();
+	if( ret == 0 ) {
+		res = MessageBoxYesNo( _("Visualiser le fichier %s ?"),  aviFile );
+		if( res == 1 )	VisuAvi( aviFile );
+	}
+	unlink( logFile );
+	return( ret );
+}
