@@ -46,7 +46,6 @@ COMMENTAIRE :
 #include "dvdinfo.h"
 #include "message.h"
 #include "gconfig.h"
-#include "tampon.h"
 #include "interface.h"
 #include "globals.h"
 #include "systools.h"
@@ -328,7 +327,7 @@ static int Readin( void * parm, unsigned char * buffer, int size )
 	c->bufSize += len;
 
 	Avancement( len );
-	if( AvancementUi( NULL ) < 0 )	return( -1 );
+	if( AvancementUi() < 0 )	return( -1 );
 	if( isNavPack( c->bufPtr ) ) {
 		Vobu_t * v;
 
@@ -371,7 +370,7 @@ static int Readin( void * parm, unsigned char * buffer, int size )
 	c->bufSize += len;
 
 	Avancement( len );
-	if( AvancementUi( NULL ) < 0 )	return( -1 );
+	if( AvancementUi() < 0 )	return( -1 );
 	if( badNavPack ) {
 		c->sector = c->dsi_next_vobu;
 		c->dsi_next_vobu  = 0;
@@ -891,7 +890,7 @@ fprintf(stderr,"FsFree(%lld) GetWantedBytes(%lld)\n", FsFree( isoDir ), GetWante
 	strcpy( TitreDvd, text );
 
 	FreeCellArray( &CellArray );
-	BuildCells( noPisteVideo, &CellArray, lastCellF );
+	BuildCells( noPisteVideo, &CellArray, lastCellF, 0 );
 
 	CurVTS = 0;
 	CurVOB = 0;
