@@ -71,23 +71,22 @@ typedef struct
 
 #define SECTOR_SZ( c )		( c->lastSector - c->startSector + 1 )
 
-/*@$#[dvdcell.c] global proto. AutoProtoSigV1.1. date: 2009/02/04 23:16:33 */
+/*@$#[dvdcell.c] global proto. AutoProtoSigV1.1. date: 2009/07/28 21:58:03 */
 #include "proto.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
-/* dvdcell.c */
-Cell_t *NewCell PROTO((CellArray_t *ca));
-TitleSet_t *NewTitleSet PROTO((TitleArray_t *ta));
-Vobu_t *NewVobu PROTO((VobuArray_t *va, uint32_t oldSector));
-int BuildCells PROTO((int noPisteVideo, CellArray_t *ca, int lastF));
-void FreeCellArray PROTO((CellArray_t *ca));
-int CountSelectedCells PROTO((CellArray_t *ca));
-void DumpVobus PROTO((Cell_t *c));
+Cell_t *NewCell(CellArray_t *ca);
+TitleSet_t *NewTitleSet(TitleArray_t *ta);
+Vobu_t *NewVobu(VobuArray_t *va, uint32_t oldSector);
+int BuildCells(int noPisteVideo, CellArray_t *ca, int lastF, int skipAngle);
+void FreeCellArray(CellArray_t *ca);
+int CountSelectedCells(CellArray_t *ca);
+void DumpVobus(Cell_t *c);
 #ifdef __cplusplus
 }
 #endif
-/*@$% end of AutoProtoSigV1.1 (Dont remove this line) [-I ../include]*/
+/*@$% end of AutoProtoSigV1.1 (Dont remove this line) []*/
 
 #endif	/* __DVDCELL_H__ */
 
