@@ -33,7 +33,6 @@ COMMENTAIRE :
 #include "dvdtools.h"
 #include "message.h"
 #include "gconfig.h"
-#include "tampon.h"
 #include "interface.h"
 #include "globals.h"
 #include "systools.h"
@@ -129,13 +128,13 @@ static char * _AudioFormat( int format )
 static char * _AudioType( int type )
 {
 	switch( type ) {
-		case 0 :	return( _("") );
+		case 0 :	return( "" );
 		case 1 :	return( _("Normal") );
 		case 2 :	return( _("Impaired") );
 		case 3 :	return( _("Director's comments") );
 		case 4 :	return( _("Alternate director's comments" ) );
 	}
-	return( _("") );
+	return( "" );
 }
 
 /***************************************************************************//**
@@ -152,7 +151,7 @@ static char * _AudioType( int type )
 static char * _SubType( int type )
 {
 	switch( type ) {
-		case 0 : return( _("") );
+		case 0 : return( "" );
 		case 1 : return( _("Normal") );
 		case 2 : return( _("Large") );
 		case 3 : return( _("Enfants") );
@@ -169,7 +168,7 @@ static char * _SubType( int type )
 		case 14 : return( _("Réalisateur large") );
 		case 15 : return( _("Réalisateur enfants") );
 	}
-	return( _("") );
+	return( "" );
 }
 /*------------------------------------------------------------------------------
 	NROFSUBP-
@@ -1317,6 +1316,19 @@ pgc_t * pgc;
 		DBG('b',fprintf(stderr,"%s: Chapitre: %d Start=%d\n", __FUNCTION__, i+1, pgc->program_map[i] ););
 	}
 
+{
+	int j;
+
+	for( j = 0; j < pgc->nr_of_cells; j++ ) {
+		cell_playback_t * cell_playback = &pgc->cell_playback[j];
+		unsigned int secSize;
+
+		secSize	= cell_playback->last_sector - cell_playback->first_sector + 1;
+
+		DBG('b',fprintf(stderr,"%s: cell %d block_type=%d block_mode=%d secSize=%s from: %u to: %u\n", __FUNCTION__, j, cell_playback->block_type, cell_playback->block_mode, LLSize2Giga((long long)secSize * SECTOR_SIZE), cell_playback->first_sector,cell_playback->last_sector ););
+	}
+}
+
 	for( i = 0; i < pgc->nr_of_programs; i++ ) {
 		unsigned int sectors = 0;
 		int next;
@@ -1328,16 +1340,42 @@ pgc_t * pgc;
 		DBG('b',fprintf(stderr,"%s: next: %d start=%d\n", __FUNCTION__, next, pgc->program_map[i] ););
 		while( cell < next - 1 ) {
 			unsigned int secSize;
+			cell_playback_t * cell_playback = &pgc->cell_playback[cell];
 
 /* cell cannot index > nr_of_cells */
 			if( cell >= pgc->nr_of_cells )	break;
-			secSize	= pgc->cell_playback[cell].last_sector - pgc->cell_playback[cell].first_sector + 1;
-			DBG('b',fprintf(stderr,"%s: i=%d cell: %d secSize=%s from: %u to: %u\n", __FUNCTION__, i, cell, LLSize2Giga((long long)secSize * SECTOR_SIZE), pgc->cell_playback[cell].first_sector,pgc->cell_playback[cell].last_sector ););
+
+			secSize	= cell_playback->last_sector - cell_playback->first_sector + 1;
+//			DBG('b',fprintf(stderr,"%s: block_type=%d block_mode=%d secSize=%s from: %u to: %u\n", __FUNCTION__, cell_playback->block_type, cell_playback->block_mode, LLSize2Giga((long long)secSize * SECTOR_SIZE), cell_playback->first_sector,cell_playback->last_sector ););
+#if IGNORE_ANGLE
+			if( cell_playback->block_type == 1  ) { /* Angle block start */
+				unsigned int start = cell_playback->first_sector;
+				unsigned int end;
+
+				while( cell_playback->block_type == 1 && cell_playback->block_mode != 3 ) {
+					cell++;
+					cell_playback = &pgc->cell_playback[cell];
+				}
+				end = cell_playback->last_sector;
+				secSize = end - start + 1;
+				DBG('b',fprintf(stderr,"%s: angle secSize=%s from: %u to: %u\n", __FUNCTION__, LLSize2Giga((long long)secSize * SECTOR_SIZE), cell_playback->first_sector,cell_playback->last_sector ););
+				sectors += secSize;
+				goto ignore;
+			}
+#endif
+			DBG('b',fprintf(stderr,"%s: i=%d cell: %d secSize=%s from: %u to: %u\n", __FUNCTION__, i, cell, LLSize2Giga((long long)secSize * SECTOR_SIZE), cell_playback->first_sector,cell_playback->last_sector ););
 			sectors += secSize;
+#if IGNORE_ANGLE
+ignore:;
+#endif
 			cell++;
 		}
+		DBG('b',fprintf(stderr,"%s: Chapter %d size=%s\n", __FUNCTION__, i, LLSize2Giga((long long)sectors * SECTOR_SIZE) ););
 		total += sectors;
-		if ((i + 1) == chapitre )	return( sectors );
+		if ((i + 1) == chapitre ) {
+			DBG('b',fprintf(stderr,"%s: total=%s\n", __FUNCTION__, LLSize2Giga((long long)sectors * SECTOR_SIZE) ););
+			return( sectors );
+		}
 	}
 	DBG('b',fprintf(stderr,"%s: total=%s\n", __FUNCTION__, LLSize2Giga((long long)total * SECTOR_SIZE) ););
 	return( total );
