@@ -15,25 +15,23 @@ COMMENTAIRE :
 #ifndef __DVDCOPY_H__
 #define __DVDCOPY_H__
 
-/*@$#[dvdcopy.c] global proto. AutoProtoSigV1.1. date: 106/01/05 21:32:04 */
+/*@$#[dvdcopy.c] global proto. AutoProtoSigV1.1. date: 2009/02/04 23:17:23 */
 #include "proto.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
-int ScanDvd( GtkWidget * forme );
-int ScanPiste( GtkWidget * forme, int noPiste );
-int ConvertDvd( GtkWidget * forme, int noPisteVideo, int noPisteAudio, int noSubtitle, int useMenuF, double factor );
-void UpdDefFactor( GtkWidget * forme, int noPisteVideo, AudioMap_t * audioMap, SubMap_t * subMap );
-void VisuDvdPiste( int noPisteVideo );
-int MilliSeconde PROTO((dvd_time_t *dt));
+/* dvdcopy.c */
+int ScanDvd PROTO((GtkWidget *forme));
+void UpdDefFactor PROTO((GtkWidget *forme, int noPisteVideo, AudioMap_t *audioMap, SubMap_t *subMap));
+long long GetMenuSize PROTO((void));
+int GetSubId PROTO((int noPisteVideo, int noPisteSub));
+int GetAudioId PROTO((int noPisteVideo, int noPisteAudio));
+int ScanPiste PROTO((GtkWidget *forme, int noPisteVideo));
+long long TotalAudioSize PROTO((int noPisteVideo, int *pDuree));
+long AudioSize PROTO((int noPisteVideo, int noPisteAudio, pgc_t *pgc));
 void VisuDvdPiste PROTO((int noPisteVideo));
 void VisuDvdStruct PROTO((char *path));
 int ExecuteMkIsoFs PROTO((char *sysCmd));
-long long GetMenuSize();
-long long TotalAudioSize( int noPisteVideo, int * pDuree );
-long AudioSize( int noPisteVideo, int noPisteAudio, pgc_t * pgc );
-int GetSubId( int noPisteVideo, int noPisteSub );
-int GetAudioId( int noPisteVideo, int noPisteAudio );
 #ifdef __cplusplus
 }
 #endif
