@@ -142,16 +142,29 @@ char * device;
 
 	Dvd = DVDOpen( device );
 	if( !Dvd ) {
+		DBG('i',fprintf(stderr,"DVDOpen failed!\n"););
 		return( -1 );
 	}
 	Ifo_zero = ifoOpen( Dvd, 0);
-	if( !Ifo_zero )	return( -1 );
+	if( !Ifo_zero )	{
+		DBG('i',fprintf(stderr,"ifoOpen failed!\n"););
+		return( -1 );
+	}
 
 	Ifo =(ifo_handle_t **)malloc((Ifo_zero->vts_atrt->nr_of_vtss + 1) * sizeof (ifo_handle_t *));
 	DBG('i',fprintf(stderr,"Loading %d ifos\n", Ifo_zero->vts_atrt->nr_of_vtss ););
 	for( i = 1; i <= Ifo_zero->vts_atrt->nr_of_vtss; i++) {
 		Ifo[i] = ifoOpen( Dvd, i );
-		if( !Ifo[i])	return(-1);
+		if( !Ifo[i]) {
+			if (i == 1) {
+				DBG('i',fprintf(stderr,"ifos could not be loaded!\n"););
+				return(-1);
+			}
+			Ifo_zero->vts_atrt->nr_of_vtss = i-1;
+			Ifo_zero->vmgi_mat->vmg_nr_of_title_sets = i-1;
+			DBG('i',fprintf(stderr,"%d ifos have been successfully loaded\n", Ifo_zero->vts_atrt->nr_of_vtss ););
+			break;
+		}
 	}
 	NrTitles = Ifo_zero->tt_srpt->nr_of_srpts;
 	return( 0 );
