@@ -85,5 +85,10 @@ extern int DeviceSpecifiedF;
 #define DBG( lvl, x )		if( lvl < 0 || DbgLevels[lvl] ) x
 #define IsLevelSet( lvl )	(DbgLevels[lvl])
 
+
+/* If we want to ignore angle cells */
+#define IGNORE_ANGLE		1
+
+
 #endif	/* __GLOBALS_H__ */
 
