@@ -44,12 +44,14 @@ COMMENTAIRE :
 #elif defined(__APPLE__)
 // TODO: DVD tests not properly implemented yet for Mac OS X
 #else
+#	include <sys/sysinfo.h>
 #	include <linux/cdrom.h>
 #	include <linux/loop.h>
 #endif
 #include <ctype.h>
 
 #include "support.h"
+#include "systools.h"
 
 #define CTEST(x)		/* Traces futiles */
 
@@ -865,3 +867,118 @@ char * GetEnv( char * evKey, char * defValue )
 	if( envValue )	return( envValue );
 	return( defValue );
 }
+
+/***************************************************************************//**
+ *	STARTTIMER-
+ * @date	2010/02/02 22:07:35
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+Timer_t * StartTimer()
+{
+	Timer_t * new =(Timer_t *)malloc( sizeof(*new ));
+	gettimeofday( &new->StartTime, NULL );
+	return( new );
+}
+
+/***************************************************************************//**
+ *	STOPTIMER-
+ * @date	2010/02/02 22:08:59
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+void StopTimer( Timer_t * timer )
+{
+	if( timer )	gettimeofday( &timer->EndTime, NULL );
+}
+
+/***************************************************************************//**
+ *	ELAPSEDTIMER-
+ * @date	2010/02/02 22:10:11
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+double ElapsedTimer( Timer_t * timer )
+{
+	double elapsedTime;
+
+	if( !timer )	return( 0 );
+	elapsedTime = timer->EndTime.tv_sec - timer->StartTime.tv_sec;
+	elapsedTime += (double)(timer->EndTime.tv_usec - timer->StartTime.tv_usec) / 1000000.0;
+	return( elapsedTime );
+}
+/***************************************************************************//**
+ *	FREETIMER-
+ * @date	2010/02/02 22:10:59
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+void FreeTimer( Timer_t * timer )
+{
+	if( timer )	free( timer );
+}
+/***************************************************************************//**
+ *	CPUPHYSMEMSIZE-
+ * @date	2010/02/04 20:49:56
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+long long CpuPhysMemSize()
+{
+	double pSize = 0;
+#ifdef linux
+	struct sysinfo info;
+
+	if( sysinfo( &info ) >= 0 ) {
+// Broken sur kernel >= 2.4.0	pSize = info.freeram + info.bufferram + info.sharedram;
+#if	LINUX_VERSION_CODE >= 0x020400
+		pSize = (double)info.totalram * (double)info.mem_unit;
+#else
+		pSize = (double)info.totalram;
+#endif
+	}
+#else
+#ifdef __FreeBSD__
+#include <sys/types.h>
+#include <sys/sysctl.h>
+	{
+		int mib[2];
+		int msize;
+		size_t len;
+
+		mib[0] = CTL_HW;
+		mib[1] = HW_USERMEM;
+		len = sizeof(msize);
+		sysctl(mib, 2, &msize, &len, NULL, 0);
+		pSize = msize;
+	}
+#endif
+#endif
+	if( pSize <= 0 )	pSize = 512.0 * 1024.0 * 1024.0;
+	return( (long long)pSize );
+}
