@@ -14,7 +14,15 @@ COMMENTAIRE :
 
 #ifndef __SYSTOOLS_H__
 #define __SYSTOOLS_H__
-/*@$#[systools.c] global proto. AutoProtoSigV1.1. date: 2009/07/07 22:23:06 */
+
+#include <sys/time.h>
+
+typedef struct {
+	struct timeval StartTime;
+	struct timeval EndTime;
+} Timer_t;
+
+/*@$#[systools.c] global proto. AutoProtoSigV1.1. date: 2010/02/04 20:55:30 */
 #include "proto.h"
 #ifdef __cplusplus
 extern "C" {
@@ -44,6 +52,11 @@ int GetNumCpu(void);
 int CanCreateFile(char *dirName);
 char *GetMkIsoTool(void);
 char *GetEnv(char *evKey, char *defValue);
+Timer_t *StartTimer(void);
+void StopTimer(Timer_t *timer);
+double ElapsedTimer(Timer_t *timer);
+void FreeTimer(Timer_t *timer);
+long long CpuPhysMemSize(void);
 #ifdef __cplusplus
 }
 #endif
