@@ -193,20 +193,19 @@ pthread_cond_t  condw = PTHREAD_COND_INITIALIZER;
 pthread_mutex_t mutr  = PTHREAD_MUTEX_INITIALIZER;
 pthread_mutex_t mutw  = PTHREAD_MUTEX_INITIALIZER;
 
-/*@$#[vaporize.c] static proto. AutoProtoSigV1.1. date: 107/06/20 22:33:08 */
+/*@$#[vaporize.c] static proto. AutoProtoSigV1.1. date: 2009/02/04 23:23:32 */
 #include "proto.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
+/* vaporize.c */
 static void _VarInit PROTO((void));
-static void scan_track_map PROTO((int *map, int ntracks));
 static void flush PROTO((void));
 static void vap_leader PROTO((void));
 static void vap_trailer PROTO((int length));
 static void vaporize PROTO((float fact));
 static void read_injections PROTO((char *filename));
 static void write_injections PROTO((char *filename));
-static void usage PROTO((void));
 static void fatal PROTO((char *fmt, ...));
 static void warning PROTO((char *fmt, ...));
 #ifdef __cplusplus
@@ -225,8 +224,8 @@ Linux!jef 2006/01/24 21:41:53
 ------------------------------------------------------------------------------*/
 
 int VaporizeInit( readFun, writeFun, preserveF )
-int (* readFun)();
-int (* writeFun)();
+int (* readFun)( void *, unsigned char *, int );
+int (* writeFun)( void *, unsigned char *, int );
 int preserveF;
 {
 	memset( spu_track_map, 0, sizeof(spu_track_map));		// subpicture track# translation map
@@ -468,8 +467,7 @@ void VaporizePacks( int * videoPacks, int * auxPacks )
 	if( videoPacks )	*videoPacks = VideoPacketSize;
 	if( auxPacks)		*auxPacks = aux_packs + nav_packs;
 }
-
-
+#if 0
 // analyze track numbers given in cmd line ("x,y,z")
 static void
 scan_track_map (int *map, int ntracks)
@@ -489,7 +487,7 @@ scan_track_map (int *map, int ntracks)
   }
   while (i++ <= ntracks && *op++);
 }
-
+#endif
 
 // lock `size' bytes in read buffer
 // i.e. ensure the next `size' input bytes are available in buffer
@@ -842,7 +840,6 @@ new_mpeg_audio_id (int id)
   int track;
 
   track = audio_track_map [id - 0xc0];
-
 // if( track )	fprintf(stderr, "%s: trackId:0x%x => 0x%x\n", __FUNCTION__, id, track -1 + 0xc0 );
   return track ? track - 1 + 0xc0 : 0;
 }
@@ -1452,7 +1449,7 @@ write_injections ( char *filename)
     fatal ("Failed writing injections file: %s: %s");
 }
 
-
+#if 0
 // let's hope this helps
 static void
 usage (void)
@@ -1473,6 +1470,7 @@ usage (void)
   stderr);
   exit (1);
 }
+#endif
 
 
 // this is a *very* sophisticated kind of error handling :-)
